@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2010-2012 Daniel Nicoletti <dantti12@gmail.com>
-    SPDX-FileCopyrightText: 2023 Mike Noe <noeerover@gmail.com>
+    SPDX-FileCopyrightText: 2023-2025 Mike Noe <noeerover@gmail.com>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,13 +12,6 @@
 #include <kcupslib_export.h>
 #include <qqmlregistration.h>
 
-struct DriverMatch {
-    QString ppd;
-    QString match;
-};
-
-typedef QList<DriverMatch> DriverMatchList;
-
 class KCUPSLIB_EXPORT PPDModel : public QStandardItemModel
 {
     Q_OBJECT
@@ -33,7 +26,6 @@ public:
     Q_ENUM(Role)
 
     explicit PPDModel(QObject *parent = nullptr);
-    void setPPDs(const QList<QVariantMap> &ppds, const DriverMatchList &driverMatch = DriverMatchList());
 
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QHash<int, QByteArray> roleNames() const override;
@@ -45,14 +37,10 @@ Q_SIGNALS:
     void loaded();
 
 private:
-    QStandardItem *createPPDItem(const QVariantMap &ppd, bool recommended);
     QStandardItem *findCreateMake(const QString &make);
 
     QList<QVariantMap> m_ppds;
     QHash<int, QByteArray> m_roles;
 };
 
-Q_DECLARE_METATYPE(DriverMatchList)
-Q_DECLARE_METATYPE(DriverMatch)
-
 #endif
